@@ -19,7 +19,7 @@ module Vmstat
     # Calculate the wired bytes based of the wired pages.
     # @return [Fixnum] wired bytes
     def wired_bytes
-      wired *  pagesize
+      wired * pagesize
     end
 
     # Calculate the active bytes based of the active pages.
@@ -43,7 +43,20 @@ module Vmstat
     # Calculate the total bytes based of all pages
     # @return [Fixnum] total bytes
     def total_bytes
-      (wired + active + inactive + free) * pagesize  
+      (wired + active + inactive + free) * pagesize
+    end
+  end
+
+  # @attr [Fixnum] available
+  #   The estimated available memory (linux)
+  #   See: https://git.kernel.org/cgit/linux/kernel/git/torvalds/linux.git/commit/?id=34e431b0ae398fc54ea69ff85ec700722c9da773
+  class LinuxMemory < Memory
+    attr_accessor :available
+
+    # Calculate the available bytes based of the active pages.
+    # @return [Fixnum] active bytes
+    def available_bytes
+      available * pagesize
     end
   end
 end
